#
# spec file for package convmv
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           convmv
Version:        2.05
Release:        2.21
Summary:        Utility to convert file names between encodings
License:        GPL-2.0-or-later
Group:          Productivity/File utilities
Url:            http://j3e.de/linux/convmv/
Source:         http://j3e.de/linux/convmv/%{name}-%{version}.tar.gz
BuildArch:      noarch

%description
convmv is meant to convert the filenames in a directory tree or a
whole file system into a different encoding, with support for
symlinks.

This is useful for converting from old 8-bit locales to UTF-8. It is
also possible to convert directories to UTF-8 that are already partly
UTF-8 encoded.

convmv can convert names to both the NFC and NFD normalization forms.
NFC is commonly used on Linux and (most?) other Unix-like OSes,
though it does not enforce it. Darwin, the base of Macintosh OS X,
enforces Normalization Form Canonical Decomposition (NFD).

%prep
%setup -q
tar -xf testsuite.tar

%build
make %{?_smp_mflags} PREFIX=%{_prefix}

%install
mkdir -p %{buildroot}%{_bindir} %{buildroot}%{_mandir}/man1
%make_install PREFIX=%{_prefix}

%check
make %{?_smp_mflags} test

%files
%doc GPL2 Changes CREDITS TODO VERSION
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%changelog
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Fix NFD acronym expansion.
- Use modern tar options.
* Fri Dec 28 2018 Petr Gajdos <pgajdos@suse.com>
- Update to 2.05:
  * allow NFC/NFD conversion on APFS volumes, add man page section
    for that filesystem
  * use case- and normalization-insensitivity workarounds also for
    parsable mode
* Sun Nov 26 2017 aavindraa@gmail.com
- Update to 2.04:
  * check for valid utf-8 also in upperlower_checkenc()
  * fix parsable output, missed the path files to run utime() on
  * add --run-parsable option to blindly run what a file generated
    with --parsable tells us to do
- includes 2.03:
  * fix man page build due to non-ASCII char
- includes 2.02:
  * add option --caseful-sz to optionally treat upper-/lowercasing
    of sz. This also fixes unwanted unidirectional lowercasing
    of U+1E9E
- cleanup with spec-cleaner
- replace wildcard with name macro
* Wed Jun 21 2017 tchvatal@suse.com
- Update to 2.01:
  * map : instead of / in SFU mapping tables
- Cleanup a bit with spec-cleaner
* Wed Dec 16 2015 pgajdos@suse.com
- updated to 2.0:
  * fix checks for NFD conversion, where convmv could run into a
    "resulting filename is ... bytes long (max: 255) error message
    for no obvious reason.
  * the --preserve-mtimes option is the default now
  * fix a bug where mtimes might not be restored in some cases
  * add --map option to support additional character mappings like
    to mapping Microsoft's illegal NTFS characters
  * issue warning if we cannot traverse a directory in recursive
    mode
* Mon Oct  6 2014 jengelh@inai.de
- Remove ancient specfile tags/sections
- Trim overly long description to the essentials
* Tue Aug 23 2011 tiwai@suse.de
- updated to version 1.15:
  add --dump-options; fix a bug in case-insensitive filesystems;
  see Changes file for details
* Mon Jul 27 2009 tiwai@suse.de
- updated to version 1.14:
  see Changes file for details
* Thu Jan 31 2008 crrodriguez@suse.de
- update to version 1.12 and fix build
- now work with Perl 5.10 using an eval block
- GPL v2 and v3 now
* Tue Jul 11 2006 mfabian@suse.de
- update to 1.10:
  + now use from_to instead of utf8::decode (which is experimental
    and might vanish in the future) to check for valid UTF-8
  + updates and cleanups of testsuite and include "0" filename
  + fix "0" filename bugs
  + take into account that charset name "utf-8" resolves to
    "utf-8-strict" in recent Perl versions
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec  9 2005 mfabian@suse.de
- Bugzilla #135497: fixed by updating to 1.09.
* Wed Aug 25 2004 mfabian@suse.de
- update to 1.08.
* Thu Mar 25 2004 mfabian@suse.de
- add patch from author Bjoern Jacke:
  do not complain about wrong from_enc if to_enc is utf8 and
  files are, too. Thanks to Kuang-che Wu.
* Wed Jan 14 2004 mfabian@suse.de
- don't build as root.
- update to 1.07.
  New since 1.05:
  * add option to undo ugly http- and ftp-like escape sequences
  * add option to upper/lowercase virtually any charset
  * for upper/lower conversion add a "dotless i" option for
    Lithuanian, Turkish and Azeri
  * check for characters not allowed in POSIX filesystems
    (just in case someone wants to try to convert to UTF-16)
  * rewrote checkenc(), no more false alarms now with "encodings"
    like MIME-Q, which can look quite different.
* Thu Aug 14 2003 mfabian@suse.de
- small update from author:
  * add file length check
* Fri Jul 25 2003 mfabian@suse.de
- update to 1.05.
  From the Changes file:
  * --qfrom/to also mask cntrl characters now
  * symlink printout splitted to get correct output
  * missing $arg in symlink fixed (bug introduced in 1.02)
  * add NFS4 issues to documentation
  * add test suite
* Wed Jul 16 2003 mfabian@suse.de
- update to 1.04.
  From the Changes file:
  * add --exec option to allow arbitrary operations
  * add --lowmem option to keep memory footprint low when millions
    of files are being converted. However this will deactivate
    symlink target checks.
  * add Samba issues to documentation
  * suppress normalization error messages in cases of invalid
    UTF-8 in checkenc()
* Mon Jun 30 2003 mfabian@suse.de
- update to 1.02.
  From the Changes file:
  * make default behaviour to not work recursively so we can
    convert a single directory, use -r to get the old (recursive)
    mode
  * work around find() oddity, which doesn't process directories
    from @ARGV
  * die on unknown option
  * check if files exist and die otherwise
* Mon May 12 2003 mfabian@suse.de
- update to 1.01
- remove patch which requires Encode::HanExtra and Encode::JIS2K
  because these two packages use "enc2xs -C" in %%post and %%postun
  now which makes on demand loading of these encodings possible
  without a "require" in convmv.
* Fri May  9 2003 mfabian@suse.de
- add patch to require Encode::HanExtra and Encode::JIS2K
  if available
* Fri May  9 2003 mfabian@suse.de
- new package: convmv 1.0.
